/*
 * Copyright 2014-2015 Canonical Ltd.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation; version 3.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

import QtQuick 2.0
import Ubuntu.Components 1.2
import Ubuntu.Components.Popups 1.0
import Ubuntu.Test 1.0

MainView {
    id: root
    width: units.gu(60)
    height: units.gu(40)
    objectName: "mainView"

    automaticOrientation: true

    Page {
        title: "Popover"

        Column {
            Button {
                objectName: "button"
                text: "Pop over"
                onClicked: PopupUtils.open(popoverComponent)
            }
            Button {
                objectName: "button_small"
                text: "Small"
                onClicked: PopupUtils.open(smallDialogComponent)
            }
            Button {
                objectName: "button_huge"
                text: "Huge"
                onClicked: PopupUtils.open(hugeDialogComponent)
            }
            Button {
                text: "Landscape"
                onClicked: UbuntuApplication.orientation = Qt.LandscapeOrientation;
            }
            Button {
                text: "Portrait"
                onClicked: UbuntuApplication.orientation = Qt.PortraitOrientation;
            }
        }

        Component {
            id: popoverComponent
            Popover {
                objectName: "popover"
                Column {
                    Button {
                        text: "Just a button"
                        onClicked: {
                            if (UbuntuApplication.orientation === Qt.LandscapeOrientation) {
                                UbuntuApplication.orientation = Qt.PortraitOrientation;
                            } else {
                                UbuntuApplication.orientation = Qt.LandscapeOrientation
                            }
                        }
                    }
                }
            }
        }

        Component {
            id: smallDialogComponent
            Dialog {
                id: smallDialog
                objectName: "dialog_small"
                Row {
                    Button {
                        text: "Just a button"
                        onClicked: {
                            if (UbuntuApplication.orientation === Qt.LandscapeOrientation) {
                                UbuntuApplication.orientation = Qt.PortraitOrientation;
                            } else {
                                UbuntuApplication.orientation = Qt.LandscapeOrientation
                            }
                        }
                    }
                    Button {
                        text: "close"
                        onClicked: PopupUtils.close(smallDialog)
                    }
                }
            }
        }

        Component {
            id: hugeDialogComponent
            Dialog {
                objectName: "dialog_huge"
                Column {
                    Repeater {
                        model: 50

                        Button {
                            objectName: "buttlet%1".arg(index)
                            text: "Button %1".arg(index)
                        }
                    }
                }
            }
        }
    }
}
